/**
 * The synchronizer-ws-server module of the TinyBase project lets you create
 * a server that facilitates synchronization between clients.
 * @see Synchronizing Data guide
 * @packageDocumentation
 * @module synchronizer-ws-server
 * @since v5.0.0
 */

import {Ids} from '../common';
import {WebSocketServer} from 'ws';

/**
 * The WsServerStats type
 */
export type WsServerStats = {
  paths?: number;
  clients?: number;
};

/**
 * The WsServer interface
 */
export interface WsServer {
  getWebSocketServer: () => WebSocketServer;
  getPaths: () => string[];
  getClientIds: (path: string) => Ids;
  getStats: () => WsServerStats;
  destroy: () => void;
}

/**
 * The createWsServer function
 * @category Creation
 */
export function createWsServer(WebSocketServer: WebSocketServer): WsServer;
